@@ -17,7 +17,8 @@ from typing import IO, Any, Dict, List, Type, Union, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_kafka.paginator import (
+from .literals import EnhancedMonitoringType
+from .paginator import (
     ListClusterOperationsPaginator,
     ListClustersPaginator,
     ListConfigurationRevisionsPaginator,
@@ -26,8 +27,6 @@ from mypy_boto3_kafka.paginator import (
     ListNodesPaginator,
     ListScramSecretsPaginator,
 )
-
-from .literals import EnhancedMonitoring
 from .type_defs import (
     BatchAssociateScramSecretResponseTypeDef,
     BatchDisassociateScramSecretResponseTypeDef,
@@ -97,7 +96,7 @@ class Exceptions:
 
 class KafkaClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -108,22 +107,22 @@ class KafkaClient:
         self, ClusterArn: str, SecretArnList: List[str]
     ) -> BatchAssociateScramSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
-        [Show boto3-stubs documentation](./client.md#batch-associate-scram-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.batch_associate_scram_secret)
+        [Show boto3-stubs documentation](./client.md#batch_associate_scram_secret)
         """
 
     def batch_disassociate_scram_secret(
         self, ClusterArn: str, SecretArnList: List[str]
     ) -> BatchDisassociateScramSecretResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
-        [Show boto3-stubs documentation](./client.md#batch-disassociate-scram-secret)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.batch_disassociate_scram_secret)
+        [Show boto3-stubs documentation](./client.md#batch_disassociate_scram_secret)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_cluster(
@@ -135,14 +134,14 @@ class KafkaClient:
         ClientAuthentication: "ClientAuthenticationTypeDef" = None,
         ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
         EncryptionInfo: "EncryptionInfoTypeDef" = None,
-        EnhancedMonitoring: EnhancedMonitoring = None,
+        EnhancedMonitoring: EnhancedMonitoringType = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
         LoggingInfo: "LoggingInfoTypeDef" = None,
         Tags: Dict[str, str] = None,
     ) -> CreateClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.create_cluster)
-        [Show boto3-stubs documentation](./client.md#create-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.create_cluster)
+        [Show boto3-stubs documentation](./client.md#create_cluster)
         """
 
     def create_configuration(
@@ -153,50 +152,50 @@ class KafkaClient:
         KafkaVersions: List[str] = None,
     ) -> CreateConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.create_configuration)
-        [Show boto3-stubs documentation](./client.md#create-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.create_configuration)
+        [Show boto3-stubs documentation](./client.md#create_configuration)
         """
 
     def delete_cluster(
         self, ClusterArn: str, CurrentVersion: str = None
     ) -> DeleteClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.delete_cluster)
-        [Show boto3-stubs documentation](./client.md#delete-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.delete_cluster)
+        [Show boto3-stubs documentation](./client.md#delete_cluster)
         """
 
     def delete_configuration(self, Arn: str) -> DeleteConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.delete_configuration)
-        [Show boto3-stubs documentation](./client.md#delete-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.delete_configuration)
+        [Show boto3-stubs documentation](./client.md#delete_configuration)
         """
 
     def describe_cluster(self, ClusterArn: str) -> DescribeClusterResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.describe_cluster)
-        [Show boto3-stubs documentation](./client.md#describe-cluster)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.describe_cluster)
+        [Show boto3-stubs documentation](./client.md#describe_cluster)
         """
 
     def describe_cluster_operation(
         self, ClusterOperationArn: str
     ) -> DescribeClusterOperationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
-        [Show boto3-stubs documentation](./client.md#describe-cluster-operation)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.describe_cluster_operation)
+        [Show boto3-stubs documentation](./client.md#describe_cluster_operation)
         """
 
     def describe_configuration(self, Arn: str) -> DescribeConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.describe_configuration)
-        [Show boto3-stubs documentation](./client.md#describe-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.describe_configuration)
+        [Show boto3-stubs documentation](./client.md#describe_configuration)
         """
 
     def describe_configuration_revision(
         self, Arn: str, Revision: int
     ) -> DescribeConfigurationRevisionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
-        [Show boto3-stubs documentation](./client.md#describe-configuration-revision)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.describe_configuration_revision)
+        [Show boto3-stubs documentation](./client.md#describe_configuration_revision)
         """
 
     def generate_presigned_url(
@@ -207,110 +206,110 @@ class KafkaClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_bootstrap_brokers(self, ClusterArn: str) -> GetBootstrapBrokersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
-        [Show boto3-stubs documentation](./client.md#get-bootstrap-brokers)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.get_bootstrap_brokers)
+        [Show boto3-stubs documentation](./client.md#get_bootstrap_brokers)
         """
 
     def get_compatible_kafka_versions(
         self, ClusterArn: str = None
     ) -> GetCompatibleKafkaVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
-        [Show boto3-stubs documentation](./client.md#get-compatible-kafka-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.get_compatible_kafka_versions)
+        [Show boto3-stubs documentation](./client.md#get_compatible_kafka_versions)
         """
 
     def list_cluster_operations(
         self, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListClusterOperationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
-        [Show boto3-stubs documentation](./client.md#list-cluster-operations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_cluster_operations)
+        [Show boto3-stubs documentation](./client.md#list_cluster_operations)
         """
 
     def list_clusters(
         self, ClusterNameFilter: str = None, MaxResults: int = None, NextToken: str = None
     ) -> ListClustersResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_clusters)
-        [Show boto3-stubs documentation](./client.md#list-clusters)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_clusters)
+        [Show boto3-stubs documentation](./client.md#list_clusters)
         """
 
     def list_configuration_revisions(
         self, Arn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationRevisionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
-        [Show boto3-stubs documentation](./client.md#list-configuration-revisions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_configuration_revisions)
+        [Show boto3-stubs documentation](./client.md#list_configuration_revisions)
         """
 
     def list_configurations(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListConfigurationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_configurations)
-        [Show boto3-stubs documentation](./client.md#list-configurations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_configurations)
+        [Show boto3-stubs documentation](./client.md#list_configurations)
         """
 
     def list_kafka_versions(
         self, MaxResults: int = None, NextToken: str = None
     ) -> ListKafkaVersionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
-        [Show boto3-stubs documentation](./client.md#list-kafka-versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_kafka_versions)
+        [Show boto3-stubs documentation](./client.md#list_kafka_versions)
         """
 
     def list_nodes(
         self, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListNodesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_nodes)
-        [Show boto3-stubs documentation](./client.md#list-nodes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_nodes)
+        [Show boto3-stubs documentation](./client.md#list_nodes)
         """
 
     def list_scram_secrets(
         self, ClusterArn: str, MaxResults: int = None, NextToken: str = None
     ) -> ListScramSecretsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
-        [Show boto3-stubs documentation](./client.md#list-scram-secrets)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_scram_secrets)
+        [Show boto3-stubs documentation](./client.md#list_scram_secrets)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def reboot_broker(self, BrokerIds: List[str], ClusterArn: str) -> RebootBrokerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.reboot_broker)
-        [Show boto3-stubs documentation](./client.md#reboot-broker)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.reboot_broker)
+        [Show boto3-stubs documentation](./client.md#reboot_broker)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: Dict[str, str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_broker_count(
         self, ClusterArn: str, CurrentVersion: str, TargetNumberOfBrokerNodes: int
     ) -> UpdateBrokerCountResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_broker_count)
-        [Show boto3-stubs documentation](./client.md#update-broker-count)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_broker_count)
+        [Show boto3-stubs documentation](./client.md#update_broker_count)
         """
 
     def update_broker_storage(
@@ -320,24 +319,24 @@ class KafkaClient:
         TargetBrokerEBSVolumeInfo: List["BrokerEBSVolumeInfoTypeDef"],
     ) -> UpdateBrokerStorageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_broker_storage)
-        [Show boto3-stubs documentation](./client.md#update-broker-storage)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_broker_storage)
+        [Show boto3-stubs documentation](./client.md#update_broker_storage)
         """
 
     def update_broker_type(
         self, ClusterArn: str, CurrentVersion: str, TargetInstanceType: str
     ) -> UpdateBrokerTypeResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_broker_type)
-        [Show boto3-stubs documentation](./client.md#update-broker-type)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_broker_type)
+        [Show boto3-stubs documentation](./client.md#update_broker_type)
         """
 
     def update_cluster_configuration(
         self, ClusterArn: str, ConfigurationInfo: "ConfigurationInfoTypeDef", CurrentVersion: str
     ) -> UpdateClusterConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
-        [Show boto3-stubs documentation](./client.md#update-cluster-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_cluster_configuration)
+        [Show boto3-stubs documentation](./client.md#update_cluster_configuration)
         """
 
     def update_cluster_kafka_version(
@@ -348,29 +347,29 @@ class KafkaClient:
         ConfigurationInfo: "ConfigurationInfoTypeDef" = None,
     ) -> UpdateClusterKafkaVersionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
-        [Show boto3-stubs documentation](./client.md#update-cluster-kafka-version)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_cluster_kafka_version)
+        [Show boto3-stubs documentation](./client.md#update_cluster_kafka_version)
         """
 
     def update_configuration(
         self, Arn: str, ServerProperties: Union[bytes, IO[bytes]], Description: str = None
     ) -> UpdateConfigurationResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_configuration)
-        [Show boto3-stubs documentation](./client.md#update-configuration)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_configuration)
+        [Show boto3-stubs documentation](./client.md#update_configuration)
         """
 
     def update_monitoring(
         self,
         ClusterArn: str,
         CurrentVersion: str,
-        EnhancedMonitoring: EnhancedMonitoring = None,
+        EnhancedMonitoring: EnhancedMonitoringType = None,
         OpenMonitoring: OpenMonitoringInfoTypeDef = None,
         LoggingInfo: "LoggingInfoTypeDef" = None,
     ) -> UpdateMonitoringResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Client.update_monitoring)
-        [Show boto3-stubs documentation](./client.md#update-monitoring)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Client.update_monitoring)
+        [Show boto3-stubs documentation](./client.md#update_monitoring)
         """
 
     @overload
@@ -378,13 +377,13 @@ class KafkaClient:
         self, operation_name: Literal["list_cluster_operations"]
     ) -> ListClusterOperationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)[Show boto3-stubs documentation](./paginators.md#listclusteroperationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)[Show boto3-stubs documentation](./paginators.md#listclusteroperationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_clusters"]) -> ListClustersPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListClusters)[Show boto3-stubs documentation](./paginators.md#listclusterspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListClusters)[Show boto3-stubs documentation](./paginators.md#listclusterspaginator)
         """
 
     @overload
@@ -392,7 +391,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configuration_revisions"]
     ) -> ListConfigurationRevisionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)[Show boto3-stubs documentation](./paginators.md#listconfigurationrevisionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)[Show boto3-stubs documentation](./paginators.md#listconfigurationrevisionspaginator)
         """
 
     @overload
@@ -400,7 +399,7 @@ class KafkaClient:
         self, operation_name: Literal["list_configurations"]
     ) -> ListConfigurationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)[Show boto3-stubs documentation](./paginators.md#listconfigurationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)[Show boto3-stubs documentation](./paginators.md#listconfigurationspaginator)
         """
 
     @overload
@@ -408,13 +407,13 @@ class KafkaClient:
         self, operation_name: Literal["list_kafka_versions"]
     ) -> ListKafkaVersionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)[Show boto3-stubs documentation](./paginators.md#listkafkaversionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)[Show boto3-stubs documentation](./paginators.md#listkafkaversionspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_nodes"]) -> ListNodesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListNodes)[Show boto3-stubs documentation](./paginators.md#listnodespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListNodes)[Show boto3-stubs documentation](./paginators.md#listnodespaginator)
         """
 
     @overload
@@ -422,5 +421,5 @@ class KafkaClient:
         self, operation_name: Literal["list_scram_secrets"]
     ) -> ListScramSecretsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.71/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)[Show boto3-stubs documentation](./paginators.md#listscramsecretspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)[Show boto3-stubs documentation](./paginators.md#listscramsecretspaginator)
         """
